@@ -41,44 +41,44 @@ class CollectHelmPlugin(CollectorPlugin):
 
         purl = PackageURL.from_string(comp.purl)
 
-        self.get_logger().info(f"Copying helm chart from {repo_url}")
-
-        source_url = os.path.join(repo_url, purl.name)
         target_dir = self.directory_for(
             purl.type, repo_url, subdir=f"{purl.name}_{purl.version}"
         )
 
-        command = [
-            "helm",
-            "fetch",
-            "--repo",
-            source_url,
-            "-d",
-            target_dir,
-            purl.name,
-            "--version",
-            purl.version,
-        ]
+        for subdir in ["", purl.name]:
+            source_url = os.path.join(repo_url, subdir)
+            self.get_logger().info(f"Copying helm chart from {source_url}")
 
-        password_list = []
-        if creds is not None:
-            command = command + [
-                "--username",
-                creds.username,
-                "--password",
-                creds.password,
+            command = [
+                "helm",
+                "fetch",
+                "--repo",
+                source_url,
+                "-d",
+                target_dir,
+                purl.name,
+                "--version",
+                purl.version,
             ]
-            password_list = [creds.password]
 
-        result = self.run_command(command, password_list)
-        if result.returncode != 0:
-            # pylint: disable=duplicate-code
-            msg = f"Failed to download {purl.name} version {purl.version} helm chart"
-            self.get_logger().error(msg)
-            return Result.retry(msg)
+            password_list = []
+            if creds is not None:
+                command = command + [
+                    "--username",
+                    creds.username,
+                    "--password",
+                    creds.password,
+                ]
+                password_list = [creds.password]
 
-        self.get_logger().info(
-            f"Complete helm chart artifact copy for {purl.to_string()}"
-        )
+            result = self.run_command(command, password_list)
+            if result.returncode == 0:
+                self.get_logger().info(
+                    f"Complete helm chart artifact copy for {purl.to_string()}"
+                )
 
-        return Result.success()
+                return Result.success()
+
+        msg = f"Failed to download {purl.name} version {purl.version} helm chart"
+        self.get_logger().error(msg)
+        return Result.retry(msg)
