@@ -53,12 +53,13 @@ class CollectYumPlugin(CollectorPlugin):
 
         artifact = _artifact_string(purl)
 
-        self.get_logger().info(f"Copying yum package from {purl}")
+        self.get_logger().info(f"Copying yum package from {comp.purl}")
 
         command = [
             self.required_commands[0],
             "-q",
             "--disableexcludes=all",
+            "--setopt=*.module_hotfixes=true",
             "--downloadonly",
             "--urls",
             artifact,
@@ -66,7 +67,10 @@ class CollectYumPlugin(CollectorPlugin):
 
         result = self.run_command(command)
         if result.returncode != 0:
-            msg = f"{self.required_commands[0]} failed to locate package for {purl}, return_code={result.returncode}"
+            msg = (
+                f"{self.required_commands[0]} failed to locate package for {comp.purl}, "
+                + f"return_code={result.returncode}"
+            )
             self.get_logger().error(msg)
 
             return Result.retry(msg)
@@ -91,6 +95,7 @@ class CollectYumPlugin(CollectorPlugin):
             self.required_commands[0],
             "-q",
             "--disableexcludes=all",
+            "--setopt=*.module_hotfixes=true",
             "--downloadonly",
             f"--destdir={target_dir}",
             artifact,
